%SIZE   Returns the size of the measurement structure.
%   SIZE(MSR,1) returns the number of label IDs.
%   SIZE(MSR,2) returns the number of measurement values for each ID.
%   SIZE(MSR) returns the number of label IDs and the number of measurement
%   values for each ID as the first and second elements, respectively, of a
%   1-by-2 array.
%   [N,M] = SIZE(MSR) returns the same values separately in N and M.

% (C) Copyright 1999-2005               Pattern Recognition Group
%     All rights reserved               Faculty of Applied Physics
%                                       Delft University of Technology
%                                       Lorentzweg 1
%                                       2628 CJ Delft
%                                       The Netherlands
%
% Cris Luengo, November 2000.
% 14 October 2005 - Improved help, reorganized code a tiny bit.

function varargout = size(a,dim)
if nargin == 1
   dim = [1,2];
   if nargout > 2
      error('Too many output arguments.');
   end
else
   if length(dim)~=1 | any(dim<1) | any(dim>2)
      error('Illegal dimension.')
   end
   if nargout > 1
      error('Too many output arguments.');
   end
end
sz = [];
if any(dim==2)
   sz = 0;
   for ii=1:length(a.data)
      sz = sz+size(a.data{ii},1);
   end
end
if any(dim==1)
   sz = [length(a.id),sz];
end
varargout = cell(1,nargout);
if nargout == 2
   varargout{1} = sz(1);
   varargout{2} = sz(2);
else
   varargout{1} = sz;
end
